==> huaweicloudsdkmrs-3.1.112-py2.py3-none-any.whl: huaweicloudsdkmrs/v2/model/expand_cluster_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ExpandClusterResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'result': 'str',
        'order_id': 'str'
    }

    attribute_map = {
        'result': 'result',
        'order_id': 'order_id'
    }

    def __init__(self, result=None, order_id=None):
        """ExpandClusterResponse

        The model defined in huaweicloud sdk

        :param result: 请求操作结果，succeeded为操作成功，failed为操作失败。非包周期节点组扩容请求下发成功时，会包含该字段且内容为success。
        :type result: str
        :param order_id: 订单ID。对包周期节点组进行扩容时，会返回本次扩容产生的订单ID，需要客户到订单支付页面进行自主支付才能真正触发扩容。
        :type order_id: str
        """
        
        super(ExpandClusterResponse, self).__init__()

        self._result = None
        self._order_id = None
        self.discriminator = None

        if result is not None:
            self.result = result
        if order_id is not None:
            self.order_id = order_id

    @property
    def result(self):
        """Gets the result of this ExpandClusterResponse.

        请求操作结果，succeeded为操作成功，failed为操作失败。非包周期节点组扩容请求下发成功时，会包含该字段且内容为success。

        :return: The result of this ExpandClusterResponse.
        :rtype: str
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this ExpandClusterResponse.

        请求操作结果，succeeded为操作成功，failed为操作失败。非包周期节点组扩容请求下发成功时，会包含该字段且内容为success。

        :param result: The result of this ExpandClusterResponse.
        :type result: str
        """
        self._result = result

    @property
    def order_id(self):
        """Gets the order_id of this ExpandClusterResponse.

        订单ID。对包周期节点组进行扩容时，会返回本次扩容产生的订单ID，需要客户到订单支付页面进行自主支付才能真正触发扩容。

        :return: The order_id of this ExpandClusterResponse.
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this ExpandClusterResponse.

        订单ID。对包周期节点组进行扩容时，会返回本次扩容产生的订单ID，需要客户到订单支付页面进行自主支付才能真正触发扩容。

        :param order_id: The order_id of this ExpandClusterResponse.
        :type order_id: str
        """
        self._order_id = order_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExpandClusterResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmrs-3.1.147-py2.py3-none-any.whl: huaweicloudsdkmrs/v2/model/expand_cluster_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ExpandClusterResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'result': 'str',
        'order_id': 'str'
    }

    attribute_map = {
        'result': 'result',
        'order_id': 'order_id'
    }

    def __init__(self, result=None, order_id=None):
        r"""ExpandClusterResponse

        The model defined in huaweicloud sdk

        :param result: 请求操作结果，succeeded为操作成功，failed为操作失败。非包周期节点组扩容请求下发成功时，会包含该字段且内容为success。
        :type result: str
        :param order_id: 订单ID。对包周期节点组进行扩容时，会返回本次扩容产生的订单ID，需要客户到订单支付页面进行自主支付才能真正触发扩容。
        :type order_id: str
        """
        
        super(ExpandClusterResponse, self).__init__()

        self._result = None
        self._order_id = None
        self.discriminator = None

        if result is not None:
            self.result = result
        if order_id is not None:
            self.order_id = order_id

    @property
    def result(self):
        r"""Gets the result of this ExpandClusterResponse.

        请求操作结果，succeeded为操作成功，failed为操作失败。非包周期节点组扩容请求下发成功时，会包含该字段且内容为success。

        :return: The result of this ExpandClusterResponse.
        :rtype: str
        """
        return self._result

    @result.setter
    def result(self, result):
        r"""Sets the result of this ExpandClusterResponse.

        请求操作结果，succeeded为操作成功，failed为操作失败。非包周期节点组扩容请求下发成功时，会包含该字段且内容为success。

        :param result: The result of this ExpandClusterResponse.
        :type result: str
        """
        self._result = result

    @property
    def order_id(self):
        r"""Gets the order_id of this ExpandClusterResponse.

        订单ID。对包周期节点组进行扩容时，会返回本次扩容产生的订单ID，需要客户到订单支付页面进行自主支付才能真正触发扩容。

        :return: The order_id of this ExpandClusterResponse.
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        r"""Sets the order_id of this ExpandClusterResponse.

        订单ID。对包周期节点组进行扩容时，会返回本次扩容产生的订单ID，需要客户到订单支付页面进行自主支付才能真正触发扩容。

        :param order_id: The order_id of this ExpandClusterResponse.
        :type order_id: str
        """
        self._order_id = order_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExpandClusterResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
